summaryrefslogtreecommitdiffstats
path: root/chrome/common/chrome_switches.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/chrome_switches.cc')
-rw-r--r--chrome/common/chrome_switches.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 925e1a4..80e26d1 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -1265,9 +1265,9 @@ const char kLoginPassword[] = "login-password";
// mode. Should completely disable extensions, sync and bookmarks.
const char kGuestSession[] = "bwsi";
// Enables overriding the path for the default offers component extension.
// Useful for testing.
-const char kOffersExtensionPath[] = "offers-ext-path";
+const char kEchoExtensionPath[] = "echo-ext-path";
// Show volume controls in status bar on ChromeOS.
const char kShowVolumeStatus[] = "show-volume-status";
@@ -1265,9 +1265,9 @@ const char kLoginPassword[] = "login-password";
// mode. Should completely disable extensions, sync and bookmarks.
const char kGuestSession[] = "bwsi";
-// Enables overriding the path for the default offers component extension.
+// Enables overriding the path for the default echo component extension.
// Useful for testing.